@@ -1,8 +1,8 @@
 import asyncio
-import logging
 import json
+import logging
 import traceback
-from typing import List, Set, TYPE_CHECKING
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Set
 
 import aiohttp
 import websockets
@@ -12,11 +12,14 @@ if TYPE_CHECKING:
 
 _LOGGER = logging.getLogger(__name__)
 
+SMARTRENT_FETCH_INTERVAL_SECONDS = 600
+
 SMARTRENT_BASE_URI = "https://control.smartrent.com/api/v2/"
 SMARTRENT_SESSIONS_URI = SMARTRENT_BASE_URI + "sessions"
 SMARTRENT_TOKENS_URI = SMARTRENT_BASE_URI + "tokens"
 SMARTRENT_HUBS_URI = SMARTRENT_BASE_URI + "hubs"
 SMARTRENT_HUBS_ID_URI = SMARTRENT_BASE_URI + "hubs/{}/devices"
+SMARTRENT_DEVICE_URI = SMARTRENT_BASE_URI + "devices/{}"
 
 SMARTRENT_WEBSOCKET_URI = (
     "wss://control.smartrent.com/socket/websocket?token={}&vsn=2.0.0"
@@ -71,7 +74,7 @@ class Client:
         self._token_exp_time = None
 
         self._subscribed_devices: Set["Device"] = set()
-        self._updater_task = None
+        self._updater_task: Optional[asyncio.Task[Any]] = None
         self._ws = None
 
     def __del__(self):
@@ -100,7 +103,7 @@ class Client:
 
     async def async_get_devices_data(self) -> List[dict]:
         """
-        Gets list of device dictonaries from SmartRent's api.
+        Gets list of device dictionaries from SmartRent's api.
         Also handles retry if token is bad
         """
         if not self._token:
@@ -118,7 +121,7 @@ class Client:
 
     async def _async_get_devices_data(self) -> List[dict]:
         """
-        Gets list of device dictonaries from SmartRent's api
+        Gets list of device dictionaries from SmartRent's api
         """
 
         hubs_resp = await self._aiohttp_session.get(
@@ -144,13 +147,44 @@ class Client:
 
         return devices_list
 
-    def get_current_token(self) -> str:
-        """Returns current token"""
-        return self._token
+    async def async_get_device_data(self, id: int) -> Dict[str, Any]:
+        """
+        Gets device dictionary from SmartRent's api.
+        Also handles retry if token is bad
+        """
+        if not self._token:
+            await self.async_refresh_token()
+
+        try:
+            res = await self._async_get_device_data(id)
+        except InvalidAuthError:
+            _LOGGER.warning("InvalidAuth detected. Trying again with updated token...")
+            await self.async_refresh_token()
+
+            res = await self._async_get_device_data(id)
+
+        return res
+
+    async def _async_get_device_data(self, id: int) -> Dict[str, Any]:
+        """
+        Gets list of device dictionary from SmartRent's api
+        """
+
+        device_resp = await self._aiohttp_session.get(
+            SMARTRENT_DEVICE_URI.format(id),
+            headers={"authorization": f"Bearer {self._token}"},
+        )
+        device_dict = await device_resp.json()
+
+        if not device_resp.ok:
+            if device_dict.get("errors", [{}])[0].get("code") == "unauthorized":
+                raise InvalidAuthError(device_dict.get("errors"))
+
+        return device_dict
 
     async def async_refresh_token(self) -> None:
         """
-        Refreshes API token from SmartRents
+        Refreshes API token from SmartRent
         """
         response = {}
         if self._refresh_token:
@@ -256,7 +290,7 @@ class Client:
             device._name,
             device._device_id,
         )
-        asyncio.create_task(ws.send(joiner))
+        await ws.send(joiner)
 
     async def _async_ws_join_devices(self, ws, devices: List["Device"]):
         """
@@ -267,6 +301,43 @@ class Client:
         _LOGGER.info("Done Joining devices!")
 
     async def _async_update_state(self):
+        """
+        Responsible for handling automatic updating of device info
+        """
+        fetch = asyncio.create_task(self._async_update_state_via_fetch())
+        ws = asyncio.create_task(self._async_update_state_via_ws())
+
+        await asyncio.gather(fetch, ws)
+
+    async def _async_update_state_via_fetch(self):
+        """
+        Connects to SmartRent rest api every
+        ``SMARTRENT_FETCH_INTERVAL_SECONDS`` seconds for updates.
+        To be ran in the background.
+        Used to get ``online`` and ``battery`` information
+        since those are not passed in through websockets events.
+
+        Calls ``_async_fetch_state`` method for each subscribed device
+        """
+        while True:
+            try:
+                await self._async_fetch_subscribed_devices_status()
+                await asyncio.sleep(SMARTRENT_FETCH_INTERVAL_SECONDS)
+
+            except Exception as exc:
+                _LOGGER.warning(
+                    "Exception occured! %s %s", type(exc).__name__, type(exc)
+                )
+                _LOGGER.warning(traceback.format_exc())
+
+                _LOGGER.warning(
+                    "Retrying fetches in %s seconds...",
+                    SMARTRENT_FETCH_INTERVAL_SECONDS,
+                )
+
+                await asyncio.sleep(SMARTRENT_FETCH_INTERVAL_SECONDS)
+
+    async def _async_update_state_via_ws(self):
         """
         Connects to SmartRent websocket and listens for updates.
         To be ran in the background.
@@ -281,11 +352,13 @@ class Client:
 
                 _LOGGER.info("Getting new token")
                 await self.async_refresh_token()
-                token = self.get_current_token()
+                token = self._token
 
+                # If coming off of a retry:
                 # Update all devices with newest data from regular api
                 # we may have missed some stats if websocket was down
-                await self._async_fetch_subscribed_devices_status()
+                if retries:
+                    await self._async_fetch_subscribed_devices_status()
 
                 uri = SMARTRENT_WEBSOCKET_URI.format(token)
 
@@ -359,7 +432,7 @@ class Client:
         )
         try:
             await self._async_send_payload(device, payload)
-        except websockets.exceptions.InvalidStatusCode as exc:
+        except websockets.exceptions.InvalidStatusCode as exc:  # type: ignore
             _LOGGER.debug(
                 'Possible issue during send_payload: "%s" '
                 "Refreshing token and retrying",
@@ -383,8 +456,8 @@ class Client:
         """
         _LOGGER.info("sending payload %s", payload)
 
-        uri = SMARTRENT_WEBSOCKET_URI.format(self.get_current_token())
+        uri = SMARTRENT_WEBSOCKET_URI.format(self._token)
 
-        async with websockets.connect(uri) as websocket:
+        async with websockets.connect(uri) as websocket:  # type: ignore
             await self._async_ws_joiner(websocket, device)
             await websocket.send(payload)
